---
title: Welcome
---
<!-- Hide the title defined above in favour of the banner displayed below while
     still listing this title in the site-wide navigation block to the left.
     Note that this is an obscure MkDocs kludge first publicized here:
     https://github.com/mkdocs/mkdocs/discussions/2431#discussioncomment-7750379
  -->
<style>
  .md-typeset h1,
  .md-content__button {
    display: none;
  }
</style>

![Beartype greets you with an open paw](https://raw.githubusercontent.com/beartype/beartype-assets/refs/heads/main/banner/logo.png)
